# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .audit_action_type import AuditActionType


class CatalogAuditLog(UniversalBaseModel):
    """
    Schema for audit log responses.
    """

    action_type: AuditActionType
    action_description: str
    user_email: typing.Optional[str] = None
    user_name: typing.Optional[str] = None
    details: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    id: str
    catalog_item_id: str
    sync_job_id: typing.Optional[str] = None
    source_name: typing.Optional[str] = None
    ip_address: typing.Optional[str] = None
    user_agent: typing.Optional[str] = None
    processing_time_ms: typing.Optional[int] = None
    error_message: typing.Optional[str] = None
    created_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
