# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .catalog_status import CatalogStatus
from .sensitivity_level import SensitivityLevel


class CatalogItemGovernanceUpdate(UniversalBaseModel):
    """
    Schema for updating governance-related fields only.

    Restricted to fields that users should be able to modify manually.
    """

    status: typing.Optional[CatalogStatus] = None
    description: typing.Optional[str] = None
    tags: typing.Optional[typing.List[str]] = None
    sensitivity_level: typing.Optional[SensitivityLevel] = None
    reason: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
