# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .catalog_item_summary import CatalogItemSummary


class CatalogTreeNode(UniversalBaseModel):
    """
    Node in a catalog tree view.
    """

    catalog_item: CatalogItemSummary
    children: typing.Optional[typing.List["CatalogTreeNode"]] = None
    is_expanded: typing.Optional[bool] = None
    selection_state: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(CatalogTreeNode)
