# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .catalog_audit_log_summary import CatalogAuditLogSummary


class RagGovernanceReport(UniversalBaseModel):
    """
    Report on RAG inclusion/exclusion changes.
    """

    total_inclusion_changes: int
    total_exclusion_changes: int
    recent_changes: typing.List[CatalogAuditLogSummary]
    most_active_users: typing.List[str]
    bulk_operations: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
