# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .collection_role import CollectionRole


class CollectionMember(UniversalBaseModel):
    """
    Schema representing a collection member.
    """

    user_id: str = pydantic.Field()
    """
    Unique identifier of the user
    """

    user_email: str = pydantic.Field()
    """
    Email address of the user
    """

    role: CollectionRole = pydantic.Field()
    """
    Role of the user in this collection
    """

    created_at: dt.datetime = pydantic.Field()
    """
    Timestamp when the user was added to the collection
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
