# This file was auto-generated by Fern from our API Definition.

import typing

BillingTransition = typing.Union[
    typing.Literal["initial_signup", "renewal", "upgrade", "downgrade", "reactivation", "trial_conversion"], typing.Any
]
