# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .user_activity_summary import UserActivitySummary


class ComplianceReport(UniversalBaseModel):
    """
    Compliance report for audit purposes.
    """

    report_period: str
    total_catalog_items: int
    items_reviewed: int
    governance_actions_taken: int
    user_activity_breakdown: typing.List[UserActivitySummary]
    automated_vs_manual_ratio: typing.Dict[str, int]
    compliance_score: float
    recommendations: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
