# This file was auto-generated by Fern from our API Definition.

import typing

AuditLogCategory = typing.Union[
    typing.Literal["Auth & Security", "Data Sync", "RAG Trace", "API/MCP Usage", "System"], typing.Any
]
