# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SyncJobAuditSummary(UniversalBaseModel):
    """
    Summary of audit entries for a sync job.
    """

    sync_job_id: str
    total_changes: int
    action_counts: typing.Dict[str, int]
    items_created: int
    items_updated: int
    items_deleted: int
    errors_encountered: int
    processing_time_stats: typing.Optional[typing.Dict[str, typing.Optional[float]]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
