# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_api_key_status import AgentApiKeyStatus


class AgentApiKeySummary(UniversalBaseModel):
    """
    Lightweight agent API key summary for lists and selectors.
    """

    id: str
    name: str
    key_prefix: str
    key_hint: str
    status: AgentApiKeyStatus
    cluster_count: typing.Optional[int] = None
    is_read_only: typing.Optional[bool] = None
    last_used_at: typing.Optional[str] = None
    expires_at: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
