# This file was auto-generated by Fern from our API Definition.

import typing

AuthenticationMethod = typing.Union[
    typing.Literal["direct", "oauth_browser", "oauth_token", "oauth_byoc", "auth_provider"], typing.Any
]
