# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OrganizationCreationValidation(UniversalBaseModel):
    """
    Response with validation results for organization creation.
    """

    can_create: bool = pydantic.Field()
    """
    Whether user can create organization with this plan
    """

    reason: typing.Optional[str] = pydantic.Field(default=None)
    """
    Reason if creation is not allowed
    """

    available_plans: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of available billing plans
    """

    has_free_organization: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether user already has a free/developer organization
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
