# This file was auto-generated by Fern from our API Definition.

import typing

BillingPeriodStatus = typing.Union[typing.Literal["active", "completed", "ended_unpaid", "trial", "grace"], typing.Any]
