# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class CatalogTreeView(UniversalBaseModel):
    """
    Complete tree view for a collection's catalog.
    """

    collection_id: str
    root_nodes: typing.List["CatalogTreeNode"]
    total_items: int
    selected_items: int
    total_chunks: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .catalog_tree_node import CatalogTreeNode  # noqa: E402, F401, I001

update_forward_refs(CatalogTreeView)
