# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .billing_plan import BillingPlan


class OrganizationCreationValidationRequest(UniversalBaseModel):
    """
    Request to validate organization creation with a specific plan.
    """

    billing_plan: BillingPlan = pydantic.Field()
    """
    Billing plan to validate
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
