# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.auth_provider_authentication import AuthProviderAuthentication
from ...types.direct_authentication import DirectAuthentication
from ...types.o_auth_browser_authentication import OAuthBrowserAuthentication
from ...types.o_auth_token_authentication import OAuthTokenAuthentication

Authentication = typing.Union[
    DirectAuthentication, OAuthTokenAuthentication, OAuthBrowserAuthentication, AuthProviderAuthentication
]
