# This file was auto-generated by Fern from our API Definition.

import typing

from .match_any import MatchAny
from .match_except import MatchExcept
from .match_phrase import MatchPhrase
from .match_text import MatchText
from .match_text_any import MatchTextAny
from .match_value import MatchValue

Match = typing.Union[MatchValue, MatchText, MatchTextAny, MatchPhrase, MatchAny, MatchExcept]
