# This file was auto-generated by Fern from our API Definition.

import typing

SourceConnectionStatus = typing.Union[
    typing.Literal["active", "pending_auth", "syncing", "error", "inactive", "pending_sync"], typing.Any
]
