# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .sync_status import SyncStatus


class SyncUpdate(UniversalBaseModel):
    """
    Schema for updating a Sync object.
    """

    name: typing.Optional[str] = None
    cron_schedule: typing.Optional[str] = None
    next_scheduled_run: typing.Optional[dt.datetime] = None
    sync_metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    status: typing.Optional[SyncStatus] = None
    temporal_schedule_id: typing.Optional[str] = None
    sync_type: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
