# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.legacy_search_response import LegacySearchResponse
from ...types.search_response import SearchResponse

SearchCollectionsReadableIdSearchPostResponse = typing.Union[SearchResponse, LegacySearchResponse]
