# This file was auto-generated by Fern from our API Definition.

import typing

AuditActionType = typing.Union[
    typing.Literal[
        "CREATE",
        "UPDATE",
        "DELETE",
        "INCLUDE_IN_RAG",
        "EXCLUDE_FROM_RAG",
        "STATUS_CHANGE",
        "DEPRECATE",
        "ARCHIVE",
        "REACTIVATE",
        "CONTENT_UPDATE",
        "RESYNC",
        "RECHUNK",
        "MOVE",
        "REPARENT",
        "REVIEW",
        "APPROVE",
        "REJECT",
        "BULK_INCLUDE",
        "BULK_EXCLUDE",
        "BULK_STATUS_CHANGE",
        "BULK_UPDATE_SENSITIVITY",
    ],
    typing.Any,
]
