# This file was auto-generated by Fern from our API Definition.

import typing

CollectionRole = typing.Union[typing.Literal["collection_owner", "collection_editor", "collection_viewer"], typing.Any]
