# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .context_cluster_summary import ContextClusterSummary


class ContextClusterCollectionStats(UniversalBaseModel):
    """
    Collection-level statistics for context clusters.
    """

    total_clusters: typing.Optional[int] = None
    active_clusters: typing.Optional[int] = None
    archived_clusters: typing.Optional[int] = None
    draft_clusters: typing.Optional[int] = None
    total_unique_items: typing.Optional[int] = None
    avg_items_per_cluster: typing.Optional[float] = None
    most_used_cluster: typing.Optional[ContextClusterSummary] = None
    least_used_cluster: typing.Optional[ContextClusterSummary] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
