# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .catalog_audit_log_summary import CatalogAuditLogSummary
from .content_update_stats import ContentUpdateStats
from .rag_governance_report import RagGovernanceReport
from .user_activity_summary import UserActivitySummary


class GovernanceActivityFeed(UniversalBaseModel):
    """
    Activity feed for governance dashboard.
    """

    recent_activities: typing.List[CatalogAuditLogSummary]
    user_activity_summary: typing.List[UserActivitySummary]
    content_update_stats: ContentUpdateStats
    rag_governance_report: RagGovernanceReport
    alerts: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
