# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CatalogCollectionStats(UniversalBaseModel):
    """
    Statistics about a collection's catalog.
    """

    total_items: int
    status_distribution: typing.Dict[str, int]
    asset_type_distribution: typing.Dict[str, int]
    rag_inclusion_stats: typing.Dict[str, int]
    total_chunks: int
    hierarchy_depth_stats: typing.Dict[str, int]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
