# This file was auto-generated by Fern from our API Definition.

import typing

SyncJobStatus = typing.Union[
    typing.Literal["created", "pending", "running", "completed", "failed", "cancelling", "cancelled"], typing.Any
]
