# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.legacy_search_request import LegacySearchRequest
from ...types.search_request import SearchRequest

SearchCollectionsReadableIdSearchPostRequestBody = typing.Union[SearchRequest, LegacySearchRequest]
